/*
 * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package com.sun.tools.visualvm.api.caching;

import com.sun.tools.visualvm.api.caching.impl.CacheFactoryImpl;
import org.openide.util.Lookup;

/**
 * Factory class for various types of {@linkplain Cache}
 * @author Jaroslav Bachorik
 */
final public class CacheFactory {
    final private static class Singleton {
        final private static CacheFactory INSTANCE = new CacheFactory();
    }
    final private CacheFactoryImpl delegate;

    private CacheFactory() {
        delegate = Lookup.getDefault().lookup(CacheFactoryImpl.class);
    }

    public static CacheFactory getInstance() {
        return Singleton.INSTANCE;
    }

    public <K,V> Cache<K,V> weakMapCache() {
        return delegate.weakMapCache();
    }
    public <K,V> Cache<K,V> weakMapCache(EntryFactory<K,V> resolver, Persistor<K,V> persistor) {
        return delegate.weakMapCache(resolver, persistor);
    }
    public <K,V> Cache<K,V> weakMapCache(Persistor<K,V> persistor) {
        return delegate.weakMapCache(persistor);
    }
    public <K,V> Cache<K,V> weakMapCache(EntryFactory<K,V> resolver) {
        return delegate.weakMapCache(resolver);
    }

    public <K,V> Cache<K,V> softMapCache() {
        return delegate.softMapCache();
    }
    public <K,V> Cache<K,V> softMapCache(EntryFactory<K,V> resolver, Persistor<K,V> persistor) {
        return delegate.softMapCache(resolver, persistor);
    }
    public <K,V> Cache<K,V> softMapCache(Persistor<K,V> persistor) {
        return delegate.softMapCache(persistor);
    }
    public <K,V> Cache<K,V> softMapCache(EntryFactory<K,V> resolver) {
        return delegate.softMapCache(resolver);
    }
}
